﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace pristaniNaMesici
{
    public partial class Form1 : Form
    {
        KomunikaceSeServerem komunikace;
        Pristavani aktualniPristavani;
        List<Pristavani> historiePristavani;

        private Image modulImage;

        private Timer timer;
        private int fps = 60;
        private bool upKeyPressed;
        private bool leftKeyPressed;
        private bool rightKeyPressed;

        private bool simulationStarted;

        public Form1()
        {
            InitializeComponent();
            komunikace = new KomunikaceSeServerem();

            KeyPreview = true;

            upKeyPressed = false;
            leftKeyPressed = false;
            rightKeyPressed = false;

            this.timer = new Timer();
            this.timer.Tick += new EventHandler(Refresh);
            this.timer.Interval = 1000/fps;
            this.timer.Start();

            this.modulImage = Properties.Resources.lunar_lander;


            this.historiePristavani = new List<Pristavani>();

            this.simulationStarted = false;

            kresliciPlocha.Height = 200;
            kresliciPlocha.Width = 200;
        }

        private void button1_Click(object sender, EventArgs e)
        {
            this.simulationStarted = true;
            aktualniPristavani = komunikace.NovePristavani();
        }

        private void label5_Click(object sender, EventArgs e)
        {

        }

        private void kresliciPlocha_Paint(object sender, PaintEventArgs e)
        {
            var kp = e.Graphics;

            
            Pen penPlosina = new Pen(System.Drawing.Color.Green, 4);
            Pen borderPen = new Pen(System.Drawing.Color.Black, 1);

            kp.DrawLine(borderPen, 0.0f, 0.0f, 0.0f, (float)kresliciPlocha.Height);
            kp.DrawLine(borderPen, 0.0f, (float)kresliciPlocha.Height - 1, (float)kresliciPlocha.Width, (float)kresliciPlocha.Height - 1);


            if (aktualniPristavani != null)
            {
                //vykresli pristavaci plosinu
                kp.DrawLine(penPlosina, new Point((int)aktualniPristavani.Plosina.L, kresliciPlocha.Height - 1), new Point((int)aktualniPristavani.Plosina.R, kresliciPlocha.Height - 1));

                var modul_x = aktualniPristavani.Modul.X + aktualniPristavani.Modul.RozmerX/2;
                var modul_y = kresliciPlocha.Height - aktualniPristavani.Modul.Y - aktualniPristavani.Modul.RozmerY/2;          

                kp.DrawImage(this.modulImage, (int)modul_x, (int)modul_y, 20, 20);
            }
            else if(simulationStarted)
            {
                if (komunikace.Zdar())
                {
                    MessageBox.Show("Zdar");
                }
                else
                {
                    MessageBox.Show("Krach");
                }

                timer.Stop();
            }
            


        }

        private void Refresh(object sender, EventArgs e)
        {
            if (simulationStarted)
            {
                komunikace.PoslatPrikaz(upKeyPressed, leftKeyPressed, rightKeyPressed);
                aktualniPristavani = komunikace.ZiskatInformaceOPristavani();
                historiePristavani.Add(aktualniPristavani);
            }

            kresliciPlocha.Refresh();
        }

        private void Form1_KeyDown(object sender, KeyEventArgs e)
        {
            switch (e.KeyCode)
            {
                case Keys.W:
                    this.upKeyPressed = true;
                    break;
                case Keys.A:
                    this.leftKeyPressed = true;
                    break;
                case Keys.D:
                    this.rightKeyPressed = true;
                    break;
                default: break;
            }
        }

        private void Form1_KeyUp(object sender, KeyEventArgs e)
        {
            switch (e.KeyCode)
            {
                case Keys.W:
                    this.upKeyPressed = false;
                    break;
                case Keys.A:
                    this.leftKeyPressed = false;
                    break;
                case Keys.D:
                    this.rightKeyPressed = false;
                    break;
                default: break;
            }
        }

        private void Form1_PreviewKeyDown(object sender, PreviewKeyDownEventArgs e)
        {
            
        }
    }
}
