﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Linq;
using System.Net;
using System.Text;
using System.Threading.Tasks;

namespace pristaniNaMesici
{

    class KomunikaceSeServerem
    {
        private string url;
        private int id;

        public KomunikaceSeServerem(string url = "http://localhost:8000/")
        {
            this.url = url;
        }

        public Pristavani NovePristavani()
        {
            var parametr = "start";
            var response = SendRequest(parametr);

            var id = int.Parse(response.Split(new string[] { "\r\n" }, StringSplitOptions.None)[0]);

            var result = ZiskatInformaceOPristavani(response);

            return result;
        }

        public Pristavani ZiskatInformaceOPristavani(string data = null)
        {
            Pristavani result;

            if (data == null)
            {
                var parametr = "stav?id=" + this.id.ToString();
                data = SendRequest(parametr);
            }

            var informaceOPristavani = data.Split(new string[] { "\r\n" }, StringSplitOptions.None);

            var modul = ZiskatAktualniStavModulu(data);

            if (modul != null)
            {
                var l_a_r = informaceOPristavani[4].Split(new string[] { " " }, StringSplitOptions.None);

                var id = int.Parse(informaceOPristavani[0]);
                this.id = id;

                var l = decimal.Parse(l_a_r[0], CultureInfo.InvariantCulture);
                var r = decimal.Parse(l_a_r[1], CultureInfo.InvariantCulture);

                result = new Pristavani()
                {
                    Modul = modul,
                    Plosina = new PristavaciPlosina()
                    {
                        L = l,
                        R = r
                    }
                };

            }
            else
            {
                result = null;
            }

            return result;
        }

        public bool Zdar()
        {
            var parametr = "stav?id=" + this.id.ToString();
            var response = SendRequest(parametr);

            bool result;

            switch (response)
            {
                case "Zdar":
                    result = true;
                    break;
                default:
                    result = false;
                    break;
            }

            return result;
        }

        public bool Krach()
        {
            var parametr = "stav?id=" + this.id.ToString();
            var response = SendRequest(parametr);

            bool result;

            switch (response)
            {
                case "Krach":
                    result = true;
                    break;
                default:
                    result = false;
                    break;
            }

            return result;
        }

        public void PoslatPrikaz(bool nahoru,bool doleva, bool doprava)
        {
            int up = nahoru ? 1 : 0;
            int left = doleva ? 1 : 0;
            int right = doprava ? 1 : 0;

            var parametr = string.Format("stav?id={0}&nahoru={1}&doleva={2}&doprava={3}", this.id, up, left, right);

            SendRequest(parametr);
        }

        private Modul ZiskatAktualniStavModulu(string data)
        {        
            try
            {
                var informaceOModulu = data.Split(new string[] { "\r\n" }, StringSplitOptions.None);
                var x_a_y = informaceOModulu[1].Split(new string[] { " " }, StringSplitOptions.None);
                var vx_a_vy = informaceOModulu[2].Split(new string[] { " " }, StringSplitOptions.None);
                var l_a_r = informaceOModulu[4].Split(new string[] { " " }, StringSplitOptions.None);

                var idPristani = int.Parse(informaceOModulu[0]);
                var x = decimal.Parse(x_a_y[0], CultureInfo.InvariantCulture);
                var y = decimal.Parse(x_a_y[1], CultureInfo.InvariantCulture);
                var v_x = decimal.Parse(vx_a_vy[0], CultureInfo.InvariantCulture);
                var v_y = decimal.Parse(vx_a_vy[1], CultureInfo.InvariantCulture);
                var palivo = decimal.Parse(informaceOModulu[3], CultureInfo.InvariantCulture);
                var l = decimal.Parse(l_a_r[0], CultureInfo.InvariantCulture);
                var r = decimal.Parse(l_a_r[1], CultureInfo.InvariantCulture);

                var result = new Modul()
                {
                    X = x,
                    Y = y,
                    V_x = v_x,
                    V_y = v_y,
                    Palivo = palivo
                };

                return result;
            }
            catch
            {
                return null;
            }

        }

        private string SendRequest(string parametr)
        {
            var url = this.url + parametr;
            HttpWebRequest request = (HttpWebRequest)WebRequest.Create(url);
            HttpWebResponse response = (HttpWebResponse)request.GetResponse();
            Stream resStream = response.GetResponseStream();

            var streamReader = new StreamReader(resStream);

            var result = streamReader.ReadToEnd();

            return result;
        }
    }

}
